@@ -1,5 +1,5 @@
 #!/usr/bin/perl -w
-# $Id: comp_tcp.pm 2209 2007-08-11 09:14:58Z rcaputo $
+# $Id: comp_tcp.pm 2675 2009-09-06 03:32:57Z rcaputo $
 
 # Exercise Server::TCP and later, when it's available, Client::TCP.
 
@@ -13,7 +13,7 @@ BEGIN {
   }
 }
 
-use Test::More tests => 30;
+use Test::More tests => 34;
 
 sub POE::Kernel::ASSERT_DEFAULT () { 1 }
 sub POE::Kernel::TRACE_DEFAULT  () { 1 }
@@ -28,6 +28,7 @@ my ($acceptor_port, $callback_port);
 
 POE::Component::Server::TCP->new(
   Port => 0,
+  Address => '127.0.0.1',
   Alias => 'acceptor_server',
   Started => sub {
     use Socket qw(sockaddr_in);
@@ -77,6 +78,7 @@ POE::Component::Server::TCP->new(
 
 POE::Component::Server::TCP->new(
   Port => 0,
+  Address => '127.0.0.1',
   Alias => 'input_server',
   ClientFilter => [ "POE::Filter::Line", Literal => "\n" ],
   Started => sub {
@@ -101,6 +103,11 @@ POE::Component::Server::TCP->new(
   ClientConnected => sub {
     pass("callback server got client connection");
   },
+  ClientPreConnect => sub {
+    pass("server got pre-connect callback");
+    ok(fileno($_[ARG0]), "ARG0 is a socket");
+    return $_[ARG0];
+  },
   ClientDisconnected => sub {
     pass("callback server got client disconnected");
   },
@@ -165,6 +172,12 @@ POE::Component::Client::TCP->new(
   RemoteAddress => '127.0.0.1',
   RemotePort    => $acceptor_port,
 
+  PreConnect => sub {
+    pass("acceptor pre connect");
+    ok(fileno($_[ARG0]), "acceptor has a socket");
+    return $_[ARG0];
+  },
+
   Connected => sub {
     pass("acceptor client connected");
     $_[HEAP]->{server}->put( "quit" );
