@@ -1,4 +1,4 @@
-# $Id: k_signals_rerun.pm 2299 2008-03-24 05:11:33Z rcaputo $
+# $Id: k_signals_rerun.pm 2665 2009-09-03 16:08:06Z rcaputo $
 # vim: filetype=perl
 
 # Yuval Kogman's test case for edge issues with rethrowing unhandled
@@ -11,7 +11,9 @@ use strict;
 use Test::More;
 
 if ($^O eq "MSWin32") {
-	plan skip_all => "Perl can't handle these tests on $^O - it crashes";
+  plan skip_all => "Perl on $^O is too fragile for this test - it crashes";
+  CORE::exit(0);
+
   eval 'use Win32::Console';
   if ($@) {
     plan skip_all => "Win32::Console is required on $^O - try ActivePerl";
@@ -22,7 +24,6 @@ if ($^O eq "MSWin32") {
   if (exists $INC{'Event.pm'}) {
     plan skip_all => "Perl crashes in this test with Event on $^O";
   }
-  plan skip_all => "Perl on $^O is too fragile for this test - it crashes";
 }
 
 plan tests => 9;
