@@ -1,5 +1,5 @@
 #!/usr/bin/perl -w
-# $Id: wheel_run.pm 2411 2009-01-30 07:04:44Z rcaputo $
+# $Id: wheel_run.pm 2671 2009-09-04 07:49:18Z rcaputo $
 
 use strict;
 use lib qw(./mylib ../mylib);
@@ -43,7 +43,7 @@ BEGIN {
 
   sub STD_TEST_COUNT () { 8 }
 
-  plan tests => 4 + 15 + 8 + 8 + 8*STD_TEST_COUNT;
+  plan tests => 4 + 15 + 8 + 8 + 8 * STD_TEST_COUNT;
 }
 
 # Turn on extra debugging output within this test program.
@@ -196,6 +196,7 @@ sub do_error {
 }
 
 # {{{ definition of the main test session
+
 sub main_perform_state {
   my $heap = $_[HEAP];
 
@@ -277,8 +278,9 @@ sub main_start {
   $heap->{expected} = [@$expected];
   &main_perform_state;
 
-  $heap->{flushes_expected} = scalar
-    grep { (!ref $_->[0]) and defined($_->[1]) } @$expected;
+  $heap->{flushes_expected} = scalar(
+    grep { (!ref $_->[0]) and defined($_->[1]) } @$expected
+  );
   $heap->{flushes} = 0;
 
   # timeout delay
@@ -290,10 +292,16 @@ sub main_start {
 my $x__ = 0;
 sub main_stop {
   my $heap = $_[HEAP];
-  # Callback timing is different for Gtk.
+
+  # Due to loop timing differences, "out delayed1" and "out
+  # immediate2" may sometimes not be flushed together.  Allow one
+  # extra flush to account for "out delayed1" going separately.
+
   $heap->{flushes_expected}++ if (
-    exists $INC{'Gtk.pm'} and $heap->{label} eq 'string/pause_resume'
+		$heap->{label} eq 'string/pause_resume' and
+    $heap->{flushes} - $heap->{flushes_expected} == 1
   );
+
   is( $heap->{flushes}, $heap->{flushes_expected},
     "$heap->{label} flush count ($$)" )
     unless $heap->{ignore_flushes};
@@ -457,18 +465,18 @@ my @two_stream_expected = (
   [ "bye", ["close"] ],
 );
 my @pause_resume_expected = (
-  [ "out init", ["stdout", "init", "out"] ],
-  [ ["pause_stdout"], undef ],
-  [ "out delayed1", undef ],
-  [ "err immediate1", ["stderr", "immediate1", "err"] ],
-  [ ["pause_stderr"], undef ],
-  [ "err delayed2", undef ],
-  [ ["resume_stdout"], ["stdout", "delayed1", "out"] ],
-  [ "out immediate2", ["stdout", "immediate2", "out"] ],
-  [ ["resume_stderr"], ["stderr", "delayed2", "err"] ],
-  [ "out immediate3", ["stdout", "immediate3", "out"] ],
-  [ "err immediate4", ["stderr", "immediate4", "err"] ],
-  [ "bye", ["close"] ],
+  [ "out init",         ["stdout", "init", "out"] ],
+  [ ["pause_stdout"],   undef ],
+  [ "out delayed1",     undef ],
+  [ "err immediate1",   ["stderr", "immediate1", "err"] ],
+  [ ["pause_stderr"],   undef ],
+  [ "err delayed2",     undef ],
+  [ ["resume_stdout"],  ["stdout", "delayed1", "out"] ],
+  [ "out immediate2",   ["stdout", "immediate2", "out"] ],
+  [ ["resume_stderr"],  ["stderr", "delayed2", "err"] ],
+  [ "out immediate3",   ["stdout", "immediate3", "out"] ],
+  [ "err immediate4",   ["stderr", "immediate4", "err"] ],
+  [ "bye",              ["close"] ],
 );
 my @killing_expected = (
   [ "out init", ["stdout", "init", "out"] ],
