@@ -1,38 +1,31 @@
 #!/usr/bin/perl -w
-# vim: ts=2 sw=2 expandtab
+# $Id: wheel_sf_ipv6.pm 2672 2009-09-05 17:56:52Z rcaputo $
 
 # Exercises Client and Server TCP components, which exercise
 # SocketFactory in AF_INET6 mode.
 
 use strict;
 use lib qw(./mylib ../mylib);
-use Socket qw(AF_INET6);
+use Socket;
 
 BEGIN {
   my $error;
 
-  eval 'use Socket::GetAddrInfo qw(:newapi getaddrinfo getnameinfo NI_NUMERICHOST NI_NUMERICSERV)';
-  if ($@) {
-    $error = "Socket::GetAddrInfo is needed for IPv6 tests";
+  eval 'use Socket6 ()';
+  if ( length($@) or not exists($INC{"Socket6.pm"}) ) {
+    $error = "Socket6 is needed for IPv6 tests";
   }
   elsif ($^O eq "cygwin") {
-    $error = (
-      "IPv6 isn't available on Cygwin, even with Socket::GetAddrInfo installed"
-    );
+    $error = "IPv6 is not available on Cygwin, even if Socket6 is installed";
   }
   else {
     my $addr;
-    eval {
-      my ($error, @addr) = getaddrinfo(
-        "localhost", 80, { family => AF_INET6 }
-      );
-      $addr = $addr[0]{addr} if @addr;
-    };
+    eval { $addr = Socket6::inet_pton(&Socket6::AF_INET6, "::1") };
     if ($@) {
-      $error = "error resolving localhost for IPv6: $@";
+      $error = "AF_INET6 not provided by Socket6.pm ... can't test this";
     }
     elsif (!defined $addr) {
-      $error = "IPv6 tests require a configured IPv6 localhost address";
+      $error = "IPv6 tests require a configured localhost address ('::1')";
     }
     elsif (!-f 'run_network_tests') {
       $error = "Network access (and permission) required to run this test";
@@ -48,11 +41,8 @@ BEGIN {
 }
 
 sub POE::Kernel::ASSERT_DEFAULT () { 1 }
-
-BEGIN {
-  package POE::Kernel;
-  use constant TRACE_DEFAULT => exists($INC{'Devel/Cover.pm'});
-}
+sub POE::Kernel::TRACE_DEFAULT  () { 1 }
+sub POE::Kernel::TRACE_FILENAME () { "./test-output.err" }
 
 use POE qw( Component::Client::TCP Component::Server::TCP );
 
@@ -70,7 +60,7 @@ diag( "packets across your localhost interface." );
 POE::Component::Server::TCP->new(
   Port               => 0,
   Address            => '::1',
-  Domain             => AF_INET6,
+  Domain             => Socket6::AF_INET6,
   Alias              => 'server',
   ClientConnected    => \&server_got_connect,
   ClientInput        => \&server_got_input,
@@ -79,19 +69,9 @@ POE::Component::Server::TCP->new(
   Error              => \&server_got_error,
   ClientError        => sub { }, # Hush a warning.
   Started            => sub {
-    eval {
-      my $socket_name = $_[HEAP]{listener}->getsockname();
-      (my ($err, $host), $tcp_server_port) = getnameinfo(
-        $socket_name, NI_NUMERICHOST | NI_NUMERICSERV
-      );
-    };
-    if (!$tcp_server_port || $@) {
-      $tcp_server_port = undef;
-      SKIP: {
-        my $errstr = @$ || 'server port undefined';
-        skip "AF_INET6 probably not supported or configured ($errstr)", 2;
-      }
-    }
+    $tcp_server_port = (
+      Socket6::unpack_sockaddr_in6($_[HEAP]->{listener}->getsockname())
+    )[0];
   },
 );
 
@@ -131,19 +111,17 @@ sub server_got_error {
 ###############################################################################
 # Start the TCP client.
 
-if ($tcp_server_port) {
-  POE::Component::Client::TCP->new(
-    RemoteAddress => '::1',
-    RemotePort    => $tcp_server_port,
-    Domain        => AF_INET6,
-    BindAddress   => '::1',
-    Connected     => \&client_got_connect,
-    ServerInput   => \&client_got_input,
-    ServerFlushed => \&client_got_flush,
-    Disconnected  => \&client_got_disconnect,
-    ConnectError  => \&client_got_connect_error,
-  );
-}
+POE::Component::Client::TCP->new(
+  RemoteAddress => '::1',
+  RemotePort    => $tcp_server_port,
+  Domain        => Socket6::AF_INET6,
+  BindAddress   => '::1',
+  Connected     => \&client_got_connect,
+  ServerInput   => \&client_got_input,
+  ServerFlushed => \&client_got_flush,
+  Disconnected  => \&client_got_disconnect,
+  ConnectError  => \&client_got_connect_error,
+);
 
 sub client_got_connect {
   my $heap = $_[HEAP];
